@@ -4,10 +4,9 @@ use strict;
 use warnings;
 
 use base qw/DBIx::Class::UUIDColumns::UUIDMaker/;
-use Data::UUID ();
 
 sub as_string {
-    return Data::UUID->new->to_string(Data::UUID->new->create);
+    return '12345678-1234-2345-3456-123456789090';
 };
 
 1;
